@@ -15,14 +15,14 @@ pub struct Song {
 
 impl fmt::Display for Song {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(f, "{} - {}", self.artists.join(", "), self.title)
+        write!(f, "{} - {}", self.title, self.artists.join(", "))
     } 
 }
 
 pub async fn get_playlist(client_id: String,
                     client_secret: String, 
                     playlist_id: String) -> Vec<Song> {
-    let client = utils::generate_client(client_id, client_secret).await;
-    let songs = playlist::get_songs(client, playlist_id).await;
+    let client = utils::get_client(client_id, client_secret).await;
+    let songs = playlist::songs(client, playlist_id).await;
     return songs;
 }
